@@ -14,13 +14,13 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
-from __future__ import absolute_import
+
+ 
 import sys
 import os
 import re
 
-from calculate.core.datavars import DataVarsCore
+from ..datavars import DataVarsCore
 from calculate.lib.utils.files import readFile
 
 _ = lambda x: x
@@ -154,8 +154,7 @@ def get_CRL(path_to_cert):
                 CN = subj[1]
 
         if subj and url:
-            from calculate.core.client.client_class import Client_suds
-            from .client_class import HTTPSClientCertTransport
+            from .client_class import Client_suds, HTTPSClientCertTransport
             # connect to ca server (url get from certificates)
             try:
                 client = Client_suds(url, transport=HTTPSClientCertTransport(
@@ -244,7 +243,7 @@ def rm_ca_from_trusted(ca_cert):
     import hashlib
 
     md5 = hashlib.md5()
-    md5.update(ca_cert)
+    md5.update(ca_cert.encode("UTF-8"))
     md5sum = md5.hexdigest()
 
     # search ca certificate in user ca list
