@@ -14,19 +14,19 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
-from __future__ import absolute_import
-import urllib2 as u2
+
+ 
+import urllib.request as u2
 import os
 import sys
 import calculate.contrib
 from suds.transport.http import HttpTransport
-import httplib #http.client in python3
-from httplib import HTTPConnection
+import httplib.client #http.client in python3
+from httplib.client import HTTPConnection
 import socket
 import ssl
 import hashlib
-from calculate.core.datavars import DataVarsCore
+from ..datavars import DataVarsCore
 from calculate.lib.datavars import DataVars
 from calculate.lib.utils.files import readFile
 from suds.client import Client
@@ -139,7 +139,7 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
             root_cert_md5 = cl_client_cert_dir + "/ca/cert_list"
 
             md5 = hashlib.md5()
-            md5.update(cert)
+            md5.update(cert.encode("UTF-8"))
             md5sum = md5.hexdigest()
             print("\n=================================================")
             print("md5sum = ", md5sum)
@@ -217,7 +217,7 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
         print('\n' + _("Subject"))
         for subj in Subject:
             print("%s : %s" % (subj[0], subj[1]))
-        ans = raw_input(_("Add the CA certificate to trusted? y/[n]:"))
+        ans = input(_("Add the CA certificate to trusted? y/[n]:"))
         if ans.lower() in ['y', 'yes']:
             list_ca_certs.append(cert)
             self.add_all_ca_cert(list_ca_certs)
@@ -245,7 +245,7 @@ class clientHTTPSConnection(httplib.HTTPSConnection):
 
         print('\n' + _('Add this server certificate to trusted (s) or'))
         print(_('Try to add the CA and root certificates to trusted (c) or'))
-        choice = raw_input(_("Quit (q)? s/c/[q]: "))
+        choice = input(_("Quit (q)? s/c/[q]: "))
         if choice.lower() in ['s', 'c']:
             # self.sock = ssl.wrap_socket(sock)
             ca_certs = self.trusted_path + "cert.list"
