@@ -14,6 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+
 from itertools import cycle
 from calculate.lib.utils.colortext import get_terminal_print, Terminal, \
     TextState, convert_xml_to_terminal, Print
@@ -76,9 +77,11 @@ class Table(tableReport):
 
 def printTable(data, header=None):
     try:
-        return Table(None, header, data, colSpan=0).printTable()
+        if any(data):
+            return Table(None, header, data, colSpan=0).printTable()
+        else:
+            return ""
     except Exception:
-        # TODO: DEBUG
         # print str(e)
         raise
 
@@ -95,7 +98,7 @@ def echo_on(f):
     return wrapper
 
 
-class TaskState(object):
+class TaskState():
     """
     Текущее состояние вывода сообщений
     """
@@ -228,10 +231,10 @@ class TaskState(object):
                 yes = _print.foreground(yes_color)("Yes")
                 no = _print.foreground(no_color)("No")
                 white_message = _print.foreground(Colors.WHITE)(message)
-                ask = raw_input(white_message + ' (%s/%s): ' % (yes, no))
+                ask = input(white_message + ' (%s/%s): ' % (yes, no))
             except (EOFError, KeyboardInterrupt):
                 ask = 'no'
-                print
+                print()
             if ask.lower() in ['n', 'no']:
                 return "no"
             if ask.lower() in ['y', 'yes']:
@@ -256,9 +259,8 @@ class TaskState(object):
         # ability answer by first letter
         firstletter = 0
         i_value, i_comment = 0, 1
-        answerByChar = map(lambda x: x[i_value][firstletter], answers)
-
-        if filter(lambda x: answerByChar.count(x) > 1, answerByChar):
+        answerByChar = [x[i_value][firstletter] for x in answers]
+        if [x for x in answerByChar if answerByChar.count(x) > 1]:
             use_getch = False
             sa = slice(0, None)
         else:
@@ -279,27 +281,25 @@ class TaskState(object):
                     raise KeyboardInterrupt
             else:
                 try:
-                    ask = raw_input(full_message)
+                    ask = input(full_message)
                 except (EOFError, KeyboardInterrupt):
                     printer("\n")
                     raise KeyboardInterrupt
             ask = ask.lower()
-            like_answers = filter(lambda x: x[i_value].startswith(ask),
-                                  answers)
+            like_answers = [x for x in answers if x[i_value].startswith(ask)]              
             if not like_answers:
                 self.state.printERROR(_('The answer is uncertain'))
                 continue
             if len(like_answers) == 1:
                 return like_answers[i_value][firstletter]
             else:
-                self.state.printERROR(_('Ambiguous answer:') +
-                                      ",".join(map(lambda x: x[i_comment],
-                                                   like_answers)))
+                self.state.printERROR(_('Ambiguous answer:') + 
+                    ",".join((x[i_comment] for x in like_answers)))
 
     @echo_on
     def askQuestion(self, message):
         self.parent.printer("\n")
-        return raw_input(message + _(":"))
+        return input(message + _(":"))
 
     def askPassword(self, message, twice):
         from calculate.lib.utils.common import getpass
@@ -348,15 +348,15 @@ class CleanState(TaskState):
             self.parent.addProgress()
 
     def printERROR(self, message):
-        super(CleanState, self).printERROR(message)
+        super().printERROR(message)
         self.parent.printer('\n')
 
     def printSUCCESS(self, message):
-        super(CleanState, self).printSUCCESS(message)
+        super().printSUCCESS(message)
         self.parent.printer('\n')
 
     def printWARNING(self, message):
-        super(CleanState, self).printWARNING(message)
+        super().printWARNING(message)
         self.parent.printer('\n')
 
 
@@ -590,7 +590,7 @@ class ProgressState(StartState):
         self.state.printWARNING(message)
 
 
-class ResultViewer(object):
+class ResultViewer():
     """
     Просмотрщик результатов
     """
@@ -685,5 +685,5 @@ class ResultViewer(object):
         return self.task_state.askQuestion(message)
 
     def printTable(self, table_name, head, body, fields=None,
-                   onClick=None, addAction=None):
+                   onClick=None, addAction=None, step=None, records=None):
         self.task_state.printTable(table_name, head, body)
