@@ -14,6 +14,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+
+ 
 import os
 import sys
 
@@ -22,7 +24,6 @@ from spyne import rpc
 from spyne import Service
 from spyne import String, Integer, Array
 
-from calculate.core.server.core_interfaces import CoreServiceInterface
 from calculate.lib.utils.files import readFile
 
 _ = lambda x: x
@@ -32,18 +33,17 @@ setLocalTranslate('cl_core3', sys.modules[__name__])
 
 __ = getLazyLocalTranslate(_)
 
-from clean import sid_monitor, monitor
-from tasks import restart, dbus_stop
-from loaded_methods import LoadedMethods
-from api_types import Message, ReturnProgress, Table
-import post_cert
-import post_request
-import send_cert
+from .clean import sid_monitor, monitor
+from .tasks import restart, dbus_stop
+from .loaded_methods import LoadedMethods
+from .api_types import Message, ReturnProgress, Table
+from . import post_cert
+from . import post_request
+from . import send_cert
 
 String.Attributes.encoding = "utf-8"
 
-# class Basic(CoreServiceInterface):
-class Basic(Service, CoreServiceInterface):
+class Basic(Service):
     """ Basic server class """
    
     SERV_VERS = 0.11
@@ -194,10 +194,10 @@ class Basic(Service, CoreServiceInterface):
                 threads.append(thread)
                 thread.daemon = True
                 thread.start()
-                print success
+                print(success)
             except Exception:
-                print failed
-        print
+                print(failed)
+        print()
 
     @staticmethod
     def killall():
@@ -220,7 +220,7 @@ class Basic(Service, CoreServiceInterface):
                 sys.stdout.write('.')
                 sys.stdout.flush()
             else:
-                print '\n' + _('All processes are closed.')
+                print('\n' + _('All processes are closed.'))
                 return 0
             time.sleep(0.5)
  
@@ -290,8 +290,7 @@ class Basic(Service, CoreServiceInterface):
 
     @rpc(Integer, String, _returns=Array(Array(String)))
     def get_methods(ctx, sid, client_type):
-        return map(lambda x: map(str, x),
-                   Basic.comb_class_ref.serv_get_methods(Basic.comb_class_ref, client_type))
+        return [[str(y) for y in x] for x in Basic.comb_class_ref.serv_get_methods(Basic.comb_class_ref, client_type)] 
 
     @rpc(Integer, _returns=Array(String))
     @LoadedMethods.core_method(rights=["get-sessions"])
@@ -370,7 +369,7 @@ class Basic(Service, CoreServiceInterface):
         for subj in subject:
             if subj[0] == 'CN':
                 return subj[1]
-        return ''
+        return b'No server host name provided'
 
     @rpc(_returns=String)
     def get_ca(ctx):
