@@ -14,19 +14,21 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import cert_cmd
-import post_request
+
+ 
+from . import cert_cmd
+from . import post_request
 import datetime
 import subprocess
 import shutil
 
-from calculate.core.client.cert_func import new_key_req
-from calculate.core.client.function import get_ip_mac_type
-from calculate.core.datavars import DataVarsCore
+from ..client.cert_func import new_key_req
+from ..client.function import get_ip_mac_type
+from ..datavars import DataVarsCore
 from calculate.lib.utils.files import (makeDirectory, pathJoin, readFile,
                                        writeFile, readFileEx)
 from calculate.lib.utils.mount import isMount
-from calculate.core.server.admin import Admins
+from .admin import Admins
 import os
 import hashlib
 import pwd
@@ -54,11 +56,11 @@ def check(cert, key):
     error_flag = 0
     if not os.path.isfile(cert):
         error_flag = 1
-        print _('Certificate %s not found') % cert
-    print key, cert
+        print(_('Certificate %s not found') % cert)
+    print(key, cert)
     if not os.path.isfile(key):
         error_flag = 1
-        print _('Private key %s not found') % key
+        print(_('Private key %s not found') % key)
     if os.path.isfile(cert) and os.path.isfile(key):
         import OpenSSL
         # check correspondence certificate and private key
@@ -69,7 +71,7 @@ def check(cert, key):
         p_key = subprocess.Popen(cmd_key.split(), stdout=subprocess.PIPE,
                                  stderr=subprocess.PIPE)
         if not p_cert.stdout.read().strip() == p_key.stdout.read().strip():
-            print _('The certificate does not match the private key')
+            print(_('The certificate does not match the private key'))
             error_flag = 1
 
         # check certificate date
@@ -84,13 +86,13 @@ def check(cert, key):
             date = datetime.datetime.now()
 
             if not_before > date:
-                print _('Certificate creation date later than current date')
+                print(_('Certificate creation date later than current date'))
                 error_flag = 1
             elif not_after < date:
-                print _('Certificate expired')
+                print(_('Certificate expired'))
                 error_flag = 1
         except ValueError:
-            print _('Failed to get certificate work date')
+            print(_('Failed to get certificate work date'))
             error_flag = 1
 
     sys.exit(error_flag)
@@ -102,15 +104,15 @@ def init(cert, key, cert_path, data_path, certbase, args, port):
 
     new_serv_cert = False
     if not check_serv_cert(cert_path):
-        print _('Generating the server certificate')
+        print(_('Generating the server certificate'))
         for step in range(2):
             args = change_args(args, step)
             create_server_cert(cert, key, cert_path, args, port)
         new_serv_cert = True
     else:
-        print _('Server certificate now exists.')
+        print(_('Server certificate now exists.'))
 
-    os.chmod(data_path, 0700)
+    os.chmod(data_path, 0o700)
 
 def force_user_cert(server_cert, cert_path, data_path, cert_base, user_name,
                     dv=None):
@@ -123,9 +125,9 @@ def force_user_cert(server_cert, cert_path, data_path, cert_base, user_name,
         return False
         
     if not check_client_cert(user_name, server_cert=server_cert):
-        print _('Generating the client certificate')
+        print(_('Generating the client certificate'))
     else:
-        print _('Regenerating the client certificate')
+        print(_('Regenerating the client certificate'))
     group = "all"
     if dv:
         admins = Admins(dv)
@@ -134,8 +136,8 @@ def force_user_cert(server_cert, cert_path, data_path, cert_base, user_name,
             admins.save()
         group = admins[user_name]
         if is_crypthome_notmount(dv, user_name):
-            print _("User profile is encrypted. Please perform user login for "
-                    "complete of certificate generation")
+            print(_("User profile is encrypted. Please perform user login for "
+                    "complete of certificate generation"))
             return
     create_client_cert(server_cert, cert_path, data_path, cert_base,
                        user_name, group)
@@ -183,7 +185,7 @@ def create_client_cert(server_cert, cert_path, data_path, certbase, user_name,
                        group="all"):
     client_cert_path = check_user_path(user_name)
     if not client_cert_path:
-        print _('no path to the client certificate')
+        print(_('no path to the client certificate'))
         return 1
     req_id = create_request(server_cert, cert_path, data_path, certbase,
                             client_cert_path, user_name)
@@ -196,7 +198,7 @@ def check_user_path(user_name):
     try:
         pwdObj = pwd.getpwnam(user_name)
     except KeyError as e:
-        print e
+        print(e)
         return None
 
     home_dir = pwdObj.pw_dir
@@ -204,7 +206,7 @@ def check_user_path(user_name):
         if not makeDirectory(home_dir):
             return None
         os.chown(home_dir, pwdObj.pw_uid, pwdObj.pw_gid)
-        os.chmod(home_dir, 0700)
+        os.chmod(home_dir, 0o700)
     calc_dir = os.path.join(home_dir, '.calculate')
     cert_dir = os.path.join(calc_dir, 'client_cert')
     for directory in [calc_dir, cert_dir]:
@@ -212,7 +214,7 @@ def check_user_path(user_name):
             if not makeDirectory(directory):
                 return None
         os.chown(directory, pwdObj.pw_uid, pwdObj.pw_gid)
-        os.chmod(directory, 0755)
+        os.chmod(directory, 0o755)
 
     for path in os.walk(cert_dir):
         os.chown(path[0], pwdObj.pw_uid, pwdObj.pw_gid)
@@ -220,7 +222,7 @@ def check_user_path(user_name):
             fn = pathJoin(path[0], _file)
             if os.path.isfile(fn):
                 os.chown(fn, pwdObj.pw_uid, pwdObj.pw_gid)
-                os.chmod(fn, 0644)
+                os.chmod(fn, 0o644)
     return cert_dir
 
 
@@ -236,15 +238,15 @@ def create_request(server_cert, cert_path, data_path, certbase,
     try:
         pwdObj = pwd.getpwnam(user_name)
     except KeyError as e:
-        print e
+        print(e)
         return None
     for files in [client_req_file, key + '_pub']:
         if os.path.exists(files):
             os.chown(files, pwdObj.pw_uid, pwdObj.pw_gid)
-            os.chmod(files, 0644)
+            os.chmod(files, 0o644)
     if os.path.exists(key):
         os.chown(key, pwdObj.pw_uid, pwdObj.pw_gid)
-        os.chmod(key, 0600)
+        os.chmod(key, 0o600)
 
     ip, mac, client_type = get_ip_mac_type()
     data = readFile(client_req_file)
@@ -279,7 +281,7 @@ def clear_localuser_certificates(certbase):
     Удалить все пользовательские сертификаты, создаваемые для локальных
     пользователей
     """
-    certdata = readFileEx(certbase, grab=True)
+    certdata = readFileEx(certbase, grab=True).decode("UTF-8")
     certdn = os.path.dirname(certbase)
     # оставляем только сертификаты, которые не содержат отметки
     # для какого локального пользователя они созданы
@@ -295,14 +297,14 @@ def clear_localuser_certificates(certbase):
         try:
             os.unlink(cert_fn)
         except OSError:
-            print _("Failed to remove local client certificate") % cert_fn
+            print(_("Failed to remove local client certificate") % cert_fn)
 
 
 def get_certificate(cert_path, data_path, certbase, client_cert_path,
                     user_name, server_cert=None):
     req_id_file = os.path.join(client_cert_path, 'req_id')
     if not os.path.exists(req_id_file):
-        print _("request not sent or file %s deleted") % req_id_file
+        print(_("request not sent or file %s deleted") % req_id_file)
         return 1
     fc = open(req_id_file, 'r')
     req_id = fc.read()
@@ -315,11 +317,11 @@ def get_certificate(cert_path, data_path, certbase, client_cert_path,
 
     req_file = os.path.join(client_cert_path, server_host_name + '.csr')
     if not os.path.exists(req_file):
-        print _('Request %s not found') % req_file
+        print(_('Request %s not found') % req_file)
         return 1
     request = readFile(req_file)
     md5 = hashlib.md5()
-    md5.update(request)
+    md5.update(request.encode("UTF-8"))
     md5sum = md5.hexdigest()
 
     result = post_request.serv_get_client_cert(
@@ -333,17 +335,17 @@ def get_certificate(cert_path, data_path, certbase, client_cert_path,
         return None
 
     if cert == '1':
-        print _('The signature request was rejected!')
+        print(_('The signature request was rejected!'))
         return 1
     elif cert == '2':
-        print _("The signature request has not been examined yet.")
-        print _("Your request ID = %s") % req_id
+        print(_("The signature request has not been examined yet."))
+        print(_("Your request ID = %s") % req_id)
         return 1
     elif cert == '3':
-        print _("The signature request does not match earlier data.")
+        print(_("The signature request does not match earlier data."))
         return 1
     elif cert == '4':
-        print _("The request was sent from another IP.")
+        print(_("The request was sent from another IP."))
         return 1
     cert_file = os.path.join(client_cert_path, server_host_name + '.crt')
     fc = open(cert_file, 'w')
@@ -352,14 +354,14 @@ def get_certificate(cert_path, data_path, certbase, client_cert_path,
 
     try:
         pwdObj = pwd.getpwnam(user_name)
-    except KeyError, e:
-        print e
+    except KeyError as e:
+        print(e)
         return None
     os.chown(cert_file, pwdObj.pw_uid, pwdObj.pw_gid)
-    os.chmod(cert_file, 0600)
+    os.chmod(cert_file, 0o600)
 
     os.unlink(req_id_file)
-    print _('Certificate saved. Your certificate ID: %s') % req_id
+    print(_('Certificate saved. Your certificate ID: %s') % req_id)
 
     if ca_root:
         clVars = DataVarsCore()
@@ -374,11 +376,11 @@ def get_certificate(cert_path, data_path, certbase, client_cert_path,
         if not os.path.isdir(ca_dir):
             os.makedirs(ca_dir)
         os.chown(ca_dir, pwdObj.pw_uid, pwdObj.pw_gid)
-        os.chmod(ca_dir, 0755)
+        os.chmod(ca_dir, 0o755)
         root_cert_md5 = os.path.join(ca_dir, "cert_list")
 
         md5 = hashlib.md5()
-        md5.update(ca_root)
+        md5.update(ca_root.encode("UTF-8"))
         md5sum = md5.hexdigest()
 
         if not os.path.exists(root_cert_md5):
@@ -408,10 +410,10 @@ def get_certificate(cert_path, data_path, certbase, client_cert_path,
             fc.write('%s %s\n' % (md5sum, filename))
             fc.close()
             os.chown(root_cert_md5, pwdObj.pw_uid, pwdObj.pw_gid)
-            os.chmod(root_cert_md5, 0644)
+            os.chmod(root_cert_md5, 0o644)
 
             if not filename:
-                print _('Field "CN" not found in the certificate!')
+                print(_('Field "CN" not found in the certificate!'))
                 return 1
 
             ca_cert = os.path.join(ca_dir, filename)
@@ -419,14 +421,14 @@ def get_certificate(cert_path, data_path, certbase, client_cert_path,
             fd.write(ca_root)
             fd.close()
             os.chown(ca_cert, pwdObj.pw_uid, pwdObj.pw_gid)
-            os.chmod(ca_cert, 0644)
+            os.chmod(ca_cert, 0o644)
 
             user_root_cert = os.path.join(ca_dir, 'ca_root.crt')
             fa = open(user_root_cert, 'a')
             fa.write(ca_root)
             fa.close()
             os.chown(user_root_cert, pwdObj.pw_uid, pwdObj.pw_gid)
-            os.chmod(user_root_cert, 0644)
+            os.chmod(user_root_cert, 0o644)
         # print _("Certificate added")
         #        else:
         #            print _("file with the CA certificate now exists")
@@ -435,7 +437,7 @@ def get_certificate(cert_path, data_path, certbase, client_cert_path,
         if not os.path.isdir(trust_dir):
             os.makedirs(trust_dir)
         os.chown(trust_dir, pwdObj.pw_uid, pwdObj.pw_gid)
-        os.chmod(trust_dir, 0755)
+        os.chmod(trust_dir, 0o755)
 
         ca_certs = os.path.join(trust_dir, "cert.list")
 
@@ -443,7 +445,7 @@ def get_certificate(cert_path, data_path, certbase, client_cert_path,
             fc = open(ca_certs, "w")
             fc.close()
             os.chown(ca_certs, pwdObj.pw_uid, pwdObj.pw_gid)
-            os.chmod(ca_certs, 0644)
+            os.chmod(ca_certs, 0o644)
 
         host = 'localhost'
         filename = host
@@ -452,7 +454,7 @@ def get_certificate(cert_path, data_path, certbase, client_cert_path,
         fc.write(ca_root)
         fc.close()
         os.chown(cert_file_trust, pwdObj.pw_uid, pwdObj.pw_gid)
-        os.chmod(cert_file_trust, 0644)
+        os.chmod(cert_file_trust, 0o644)
         with open(ca_certs) as fd:
             t = fd.read()
             # for each line
@@ -474,7 +476,7 @@ def get_certificate(cert_path, data_path, certbase, client_cert_path,
 def key_force(cert_path, data_path):
     while True:
         try:
-            resp = raw_input(_('Do you really want to remove all '
+            resp = input(_('Do you really want to remove all '
                                'certificates, requests and config files from '
                                'the server?') + ' (yes/no): ')
         except KeyboardInterrupt:
