@@ -17,9 +17,9 @@
 import sys
 import os
 from calculate.lib.utils.tools import unpack_single_opts
-import cert_cmd
+from . import cert_cmd
 import pwd
-from calculate.core.server.func import clearDataVars
+from .func import clearDataVars
 
 from calculate.lib.cl_lang import setLocalTranslate
 
@@ -31,7 +31,7 @@ from spyne.protocol.soap import Soap11
 from spyne import Application
 # from spyne.server.wsgi import WsgiApplication
 
-from spyne_adapter import CoreInnerWsdl, make_service
+from .spyne_adapter import CoreInnerWsdl, make_service
 
 _ = lambda x: x
 setLocalTranslate('cl_core3', sys.modules[__name__])
@@ -44,7 +44,10 @@ _('No module named %s')
 @clearDataVars
 def main(*args, **keywords):
     _args = list(unpack_single_opts(sys.argv[1:]))
-    if os.path.basename(sys.argv[0]) != 'cl-core':
+    caller = os.path.basename(sys.argv[0]) 
+    #TODO uncomment
+    # if not (caller == 'cl-core' or caller == 'cl-core_py3'):
+    if False:
         parser = cert_cmd.parse(full=False)
         args, unknown_args = parser.parse_known_args(_args)
         args.method = '_temp_'
@@ -62,7 +65,7 @@ def main(*args, **keywords):
         parser.print_help()
         return 0
 
-    from calculate.core.datavars import DataVarsCore
+    from ..datavars import DataVarsCore
 
     ob = DataVarsCore()
     ob.importCore()
@@ -96,14 +99,14 @@ def main(*args, **keywords):
 
     # создать симлинки на команды
     if not args.method and args.create_symlink:
-        from func import create_symlink, initialization
+        from .func import create_symlink, initialization
 
         initialization(cl_wsdl)
         create_symlink(local_data_path, data_path)
         return 0
 
     if args.version:
-        print cl_ver
+        print(cl_ver)
         return 0
 
     log_filename = None
@@ -137,7 +140,7 @@ def main(*args, **keywords):
         except IOError:
             pass
 
-        from urllib2 import URLError
+        from urllib.error import URLError
 
     from traceback import print_exc
 
@@ -146,19 +149,19 @@ def main(*args, **keywords):
         try:
             port = args.port or cl_core_port
             if args.check:
-                import bootstrap
+                from . import bootstrap
 
                 bootstrap.check(cert, key)
                 return 0
 
             if args.bootstrap_user_name:
-                import bootstrap
+                from . import bootstrap
                 bootstrap.init(cert, key, cert_path, data_path, certbase, args,
                                port)
                 if not args.cert_user_name:
                     return 0
             if args.clear_user_cert:
-                import bootstrap
+                from . import bootstrap
                 bootstrap.clear_localuser_certificates(certbase)
                 if not args.cert_user_name:
                     return 0
@@ -167,10 +170,10 @@ def main(*args, **keywords):
                 try:
                     pwd.getpwnam(cert_user_name)
                 except KeyError:
-                    print _("User %s does not exist") % cert_user_name
+                    print(_("User %s does not exist") % cert_user_name)
                     return 1
 
-                import bootstrap
+                from . import bootstrap
                 bootstrap.force_user_cert(cert, cert_path, data_path,
                                           certbase, cert_user_name, dv=ob)
                 return 0
@@ -206,14 +209,14 @@ def main(*args, **keywords):
                                      serv_certbase, certbase, data_path)
                 return 0
         except BaseException as e:
-            from urllib2 import URLError
+            from urllib.error import URLError
 
             if isinstance(e, URLError) and log_filename:
                 if file_logger:
                     fd = open(log_filename, 'a')
                     file_logger.debug(print_exc(file=fd))
                     fd.close()
-                print e
+                print(e)
             else:
                 raise
     params_list = ["start", "create_symlink", "method",
@@ -226,36 +229,30 @@ def main(*args, **keywords):
         return 0
     #####################
     # importing other modules
-    from func import initialization
+    from .func import initialization
 
     outer_wsdl_classes = initialization(cl_wsdl)
     
     pack = "calculate.core.server"
     import importlib
 
-    func_metaclass = importlib.import_module('%s.func_metaclass' % pack)
-    core_wsdl_classes = []
-    core_wsdl_classes.append(func_metaclass.Func_MetaClass)
-
-    from calculate.core.server.baseClass import Basic
+    core_wsdl_classes = importlib.import_module('%s.func_metaclass' % pack).Func_MetaClass
+    from .baseClass import Basic
     # make server metaclass
     if args.method or args.list_methods:
-        from local_call import local_method, LocalCall
+        from .local_call import local_method, LocalCall
 
         ClService = CoreInnerWsdl("ClService",
-                                   tuple([LocalCall] + outer_wsdl_classes + [Basic] + core_wsdl_classes), 
+                                   tuple([LocalCall] + outer_wsdl_classes + [Basic] + [core_wsdl_classes]), 
                                    {
                                         "__metaclass__" : CoreInnerWsdl
                                    })
-        tc = ClService()
-        tc.set_comb_class_ref(tc)
-        return local_method(tc, args, unknown_args)
+        # tc = ClService()
+        ClService.set_comb_class_ref(ClService)
+        return local_method(ClService, args, unknown_args)
 
     ClService = make_service(Basic, core_wsdl_classes, outer_wsdl_classes, "ClService")
-
-    from server_class import ClApplication, OpenSSLAdapter
-    #do we even need this anymore?
-    tc = ClService() 
+    from .server_class import ClApplication, OpenSSLAdapter
     App = Application([ClService], 'tns',
         name="ClApplication",
         in_protocol=Soap11(),
@@ -265,32 +262,30 @@ def main(*args, **keywords):
     wsgi_application = ClApplication(App, log=file_logger)
     cert_cmd.create_path(data_path, certbase, rights, group_rights,
                          local_data_path)
-
+    
     # set all path
-    tc.set_paths(data_path, certbase, serv_certbase,
+    ClService.set_paths(data_path, certbase, serv_certbase,
                  rights, group_rights, sids, pids, sids_pids, 
                  sids_file, pids_file, max_sid,
                  max_pid, cert_path, log_filename, 
                  cert, key)
 
-    tc.set_comb_class_ref(tc)
-    tc.run_tasks()
+    # tc.set_comb_class_ref(tc)
+    ClService.run_tasks()
 
     
 
     max_num = 99999999
     import calculate.contrib
-    from cherrypy.wsgiserver import CherryPyWSGIServer, WSGIPathInfoDispatcher
-
-    dispatcher = WSGIPathInfoDispatcher({'': wsgi_application})
-    server = CherryPyWSGIServer(('0.0.0.0', port), dispatcher,
+    from cheroot import wsgi
+    server = wsgi.Server(('0.0.0.0', port), wsgi_application,
                                 numthreads=10, max=max_num,
                                 request_queue_size=max_num)
 
     # logger = logging.getLogger("spyne.application")
     # logger.setLevel(0)
-    print _("listening to https://0.0.0.0:%d") % port
-    print _("wsdl is located at: https://0.0.0.0:%d/?wsdl") % port
+    print(_("listening to https://0.0.0.0:%d") % port)
+    print(_("wsdl is located at: https://0.0.0.0:%d/?wsdl") % port)
 
         
 
@@ -330,13 +325,13 @@ def main(*args, **keywords):
                                  % args.pidfile + "\n")
                 sys.exit(1)
         # For cleaning of sessions at server reboot
-        from clean import clean
-        from gen_pid import clear_finished_pids
+        from .clean import clean
+        from .gen_pid import clear_finished_pids
         from calculate.lib.utils.files import writeFile
 
         clean(sids_file, pids_file, sids_pids, sids, pids)
         clear_finished_pids(ob)
-        print _("Server started")
+        print(_("Server started"))
         dbus_stop_file = ob.Get('cl_core_dbus_stop_path')
         if args.inactiveclose:
             try:
@@ -352,23 +347,23 @@ def main(*args, **keywords):
             ClService.killall()
         except KeyboardInterrupt:
             pass
-        print '\n' + _("Server stopped")
+        print('\n' + _("Server stopped"))
         server.stop()
         sys.exit(0)
-    except socket.error, e:
-        if e.message == "No socket could be created":
-            print _("No socket could be created")
-            print _('Port %d already in use') % port
+    except socket.error as e:
+        if e == "No socket could be created":
+            print(_("No socket could be created"))
+            print(_('Port %d already in use') % port)
         else:
             if file_logger:
                 fd = open(log_filename, 'a')
                 file_logger.debug(print_exc(file=fd))
                 fd.close()
-            print e
+            print(e)
     except SSLError:
-        print '\n', _('Server certificate not found')  # , e
-        print _("use cl-core with option --gen-cert-by HOST "
-                "(--get-cert-from HOST) or --use-root-as-server)")
+        print('\n', _('Server certificate not found'))  # , e
+        print(_("use cl-core with option --gen-cert-by HOST "
+                "(--get-cert-from HOST) or --use-root-as-server)"))
     except Exception:
         if file_logger:
             fd = open(log_filename, 'a')
