@@ -14,6 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+
 import sys
 from M2Crypto import RSA, X509, EVP, m2
 from calculate.lib.cl_lang import setLocalTranslate
@@ -52,7 +53,7 @@ def makeRequest(pubkey, pkey, serv_host, port):
     req.set_version(req.get_version())
     req.set_pubkey(pkey)
     name = X509.X509_Name()
-    c = raw_input(_("Enter the certificate date manually? [y]/n: "))
+    c = input(_("Enter the certificate date manually? [y]/n: "))
     if c.lower() in ['n', 'no']:
         name.CN = 'root_cert'  # (Common Name);
         name.OU = 'www.calculate-linux.ru'  # (Organization Unit);
@@ -63,7 +64,7 @@ def makeRequest(pubkey, pkey, serv_host, port):
     else:
         import socket
 
-        print _('Do not use spaces or tabs.')
+        print(_('Do not use spaces or tabs.'))
         host_name = socket.getfqdn()
         # if serv_host == host_name:
         # print '\n'+_("Want to create self-signed certificate?\n"
@@ -72,7 +73,7 @@ def makeRequest(pubkey, pkey, serv_host, port):
         if serv_host in host_name:
             host_name = host_name.replace('.' + serv_host, '')
             list_host_name = host_name.split('.')
-            print 'list_host_name = ', list_host_name
+            print('list_host_name = ', list_host_name)
             result_host_name = \
                 list_host_name[len(list_host_name) - 1] + "." + serv_host
         else:
@@ -85,18 +86,18 @@ def makeRequest(pubkey, pkey, serv_host, port):
                 return x.replace(' ', '_').replace('\t', '_')
             return ""
 
-        _CN = raw_input(_('Hostname [%s] : ') % _u8(result_host_name))
+        _CN = input(_('Hostname [%s] : ') % _u8(result_host_name))
         name.CN = _CN or result_host_name or ""
-        _OU = raw_input(_('Organization unit: '))
+        _OU = input(_('Organization unit: '))
         name.OU = cleardata(_OU)
-        _O = raw_input(_('Organization name: '))
+        _O = input(_('Organization name: '))
         name.O = cleardata(_O)
         network = _('Full network address (host:port)')
-        _L = raw_input(network + ' [%s:%d]: ' % (_u8(host_name), port))
+        _L = input(network + ' [%s:%d]: ' % (_u8(host_name), port))
         name.L = cleardata(_L) or (_u8(host_name) + ':' + str(port))
-        _ST = raw_input(_('City: '))
+        _ST = input(_('City: '))
         name.ST = cleardata(_ST)
-        _C = raw_input(_('Country (two letters only!): '))
+        _C = input(_('Country (two letters only!): '))
         name.C = _C or "C"
 
     req.set_subject_name(name)
@@ -141,7 +142,7 @@ def create_selfsigned_ca(dn_data, keyfile, certfile):
         ca.add_extensions([crypto.X509Extension(b'authorityKeyIdentifier', False, b'keyid:always',issuer=ca)])
         ca.sign(pkey, 'sha1')
 
-        with writeFile(certfile) as f:
+        with writeFile(certfile, binary=True) as f:
             f.write(crypto.dump_certificate(crypto.FILETYPE_PEM, ca))
     except crypto.Error as e:
         raise CreateCertError(str(e))
@@ -179,11 +180,11 @@ def sign_client_certifacation_request(ca_keyfile, ca_certfile, requestfile, out_
             crypto.X509Extension(b'nsCertType', False, b'client'),
             crypto.X509Extension(b'keyUsage', False, b'digitalSignature, keyEncipherment'),
             crypto.X509Extension(b'extendedKeyUsage', False, b'clientAuth'),
-            crypto.X509Extension(b'nsComment', False, 'group:{}'.format(group)),
+            crypto.X509Extension(b'nsComment', False, 'group:{}'.format(group).encode("UTF-8")),
         ])
         cert.sign(pkey, 'sha1')
 
-        with writeFile(out_cert) as f:
+        with writeFile(out_cert, binary=True) as f:
             f.write(crypto.dump_certificate(crypto.FILETYPE_PEM, cert))
     except crypto.Error as e:
         raise CreateCertError(str(e))
