@@ -14,8 +14,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
-from __future__ import absolute_import
+
+ 
 import pickle
 import random
 import threading
@@ -26,12 +26,10 @@ from os import path
 import glob
 import traceback
 from traceback import print_exc
-from calculate.core.server.core_interfaces import (CoreServiceInterface,
-                                                   MethodsInterface)
+from .core_interfaces import (CoreServiceInterface, MethodsInterface)
 from calculate.install.distr import Distributive
 from calculate.lib.cl_log import log
 from calculate.lib.utils.colortext import convert_console_to_xml
-from .api_types import ReturnProgress
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 
 _ = lambda x: x
@@ -48,9 +46,8 @@ from itertools import *
 import calculate.contrib
 from spyne import String, Integer, Boolean, Array
 
-from calculate.core.server.api_types import ReturnedMessage, CommonInfo
-from calculate.core.server.api_types import (Field,
-                                             GroupField, ViewInfo, ViewParams)
+from .api_types import ReturnedMessage, CommonInfo, ReturnProgress
+from .api_types import (Field, GroupField, ViewInfo, ViewParams)
 from calculate.lib.cl_template import Template
 from calculate.lib.datavars import DataVars
 from .loaded_methods import LoadedMethods
@@ -76,9 +73,8 @@ class CommonMethods(MethodsInterface):
         i_orig, i_data = 0, 1
         i_mime, i_cfgname = 0, 1
         cfg_files = getCfgFiles(prefix=prefix).items()
-        info = filter(lambda x: (filesApply is None or
-                                 x[i_data][0][i_cfgname] in filesApply),
-                      cfg_files)
+        info = [x for x in cfg_files 
+            if filesApply is None or x[i_data][0][i_cfgname] in filesApply]
         max_info = len(info)
         for ind, data in enumerate(info):
             out = []
@@ -222,7 +218,7 @@ class CommonMethods(MethodsInterface):
         return True
 
 
-class CommonLink(object):
+class CommonLink():
     """
     Объект-связка объектов тип Install,Client,Action с Common объектом
     """
@@ -246,7 +242,7 @@ class ActionError(Exception):
     pass
 
 
-class Tasks(object):
+class Tasks():
     """
     Класс для создания проверок необходимости запуска задачи в зависимости
     от результатра работы предыдущих задач
@@ -488,7 +484,7 @@ class Action(MethodsInterface):
             return dv.Get(param)
 
         if args:
-            args = map(_convertMethodArg, args.split(','))
+            args = [_convertMethodArg(x) for x in args.split(',')]
         else:
             args = ()
         return getattr(obj, methodname), args
@@ -498,7 +494,7 @@ class Action(MethodsInterface):
         Вставить значения переменных в текст сообщения
         """
 
-        class TextTrasformer(object):
+        class TextTrasformer():
 
             @staticmethod
             def first_letter_upper(s):
@@ -622,7 +618,7 @@ class Action(MethodsInterface):
     def run(self, objs, dv):
         """Запустить список действий"""
 
-        class StubLogger(object):
+        class StubLogger():
             def info(self, s):
                 pass
 
@@ -743,17 +739,15 @@ class Action(MethodsInterface):
                             # запустить системную команду
                             if "command" in action:
                                 hideout = action.get("hideout", False)
-                                cmdParam = map(lambda x: x.strip('"\''),
-                                               re.findall(
-                                                   '["\'][^"\']+["\']|\S+',
-                                                   action["command"]))
+                                cmdParam = [x.strip('"\'') for x 
+                                    in re.findall('["\'][^"\']+["\']|\S+', action["command"])]          
                                 cmd = processProgress(*cmdParam)
                                 for line in cmd.progress():
                                     if not hideout:
                                         self.printSUCCESS(line)
                                 if cmd.failed():
                                     lineCmd = cmd.pipe.stderr.read().split('\n')
-                                    for line in filter(None, lineCmd):
+                                    for line in (x for x in lineCmd if x):
                                         self.printERROR(line)
                                 res = cmd.success()
                             all_result[name] = res
@@ -814,15 +808,15 @@ class Action(MethodsInterface):
         return True
 
 # Never used. Why do we need it?
-# def commonView(self, sid, params, arg):
-#     dv = self.get_cache(sid, arg, "vars")
-#     if not dv:
-#         dv = getattr(self, "%s_vars" % arg)()
-#     else:
-#         dv.processRefresh()
-#     view = ViewInfo(dv, viewparams=params)
-#     self.set_cache(sid, arg, "vars", dv, smart=False)
-#     return view
+def commonView(self, sid, params, arg):
+    dv = self.get_cache(sid, arg, "vars")
+    if not dv:
+        dv = getattr(self, "%s_vars" % arg)()
+    else:
+        dv.processRefresh()
+    view = ViewInfo(dv, viewparams=params)
+    self.set_cache(sid, arg, "vars", dv, smart=False)
+    return view
 
 
 def catchExcept(*skipException):
@@ -839,7 +833,7 @@ def catchExcept(*skipException):
             try:
                 return self.f(*args, **kwargs)
             except BaseException as e:
-                from calculate.core.server.api_types import ViewInfo, \
+                from .api_types import ViewInfo, \
                     GroupField, Field
 
                 if isinstance(e, KeyboardInterrupt):
@@ -889,7 +883,7 @@ def shortTraceback(e1, e2, e3):
     return "%s:%s(%s:%s)" % (e1.__name__, str(e2), modname, frame.tb_lineno)
 
 
-class ActiveClientStatus(object):
+class ActiveClientStatus():
     Success = 0
     Failed = 1
     WrongSID = 2
@@ -919,7 +913,7 @@ class CoreWsdl(CoreServiceInterface):
                         pass
                     return ActiveClientStatus.Failed
                 with cls.sid_locker:
-                    with open(sid_file) as fd:
+                    with open(sid_file, "rb") as fd:
                         # read information about session
                         sid_inf = pickle.load(fd)
                         # reset counters
@@ -928,7 +922,7 @@ class CoreWsdl(CoreServiceInterface):
                     fd.close()
                     if not os.path.isfile(sid_file):
                         return ActiveClientStatus.Failed
-                    fd = open(sid_file, "w")
+                    fd = open(sid_file, "wb")
                     pickle.dump(sid_inf, fd)
                     fd.close()
                 return ActiveClientStatus.Success
@@ -945,7 +939,7 @@ class CoreWsdl(CoreServiceInterface):
 
         cert_id = find_cert_id(certificate, cls.data_path, cls.certbase)
 
-        rights = cls.serv_view_cert_right(cert_id, cls.data_path, client_type)
+        rights = cls.serv_view_cert_right(cls, cert_id, cls.data_path, client_type)
         return_list = []
         if client_type == "console":
             for meth in cls.return_conMethod():
@@ -987,7 +981,6 @@ class CoreWsdl(CoreServiceInterface):
     @staticmethod
     def return_guiMethod():
         from .loaded_methods import LoadedMethods
-
         results = []
         dv = DataVars()
         dv.importVariables()
@@ -1010,7 +1003,7 @@ class CoreWsdl(CoreServiceInterface):
     @staticmethod
     def serv_get_sessions(cls):
         result = []
-        fd = open(cls.sids_file, 'r')
+        fd = open(cls.sids_file, 'rb')
         while 1:
             try:
                 # read all on one record
@@ -1029,7 +1022,7 @@ class CoreWsdl(CoreServiceInterface):
         if not os.path.isfile(sid_path):
             return 1
         with cls.sid_locker:
-            with open(sid_path) as fd:
+            with open(sid_path, "rb") as fd:
                 # read information about session
                 sid_inf = pickle.load(fd)
                 # flag absence client
@@ -1053,13 +1046,13 @@ class CoreWsdl(CoreServiceInterface):
             self.Num = 100000
 
         def pauseProcess(self):
-            from calculate.core.server.gen_pid import ProcessStatus
+            from .gen_pid import ProcessStatus
 
             self.method_status = ProcessStatus.Paused
             self.writeFile()
 
         def resumeProcess(self):
-            from calculate.core.server.gen_pid import ProcessStatus
+            from .gen_pid import ProcessStatus
 
             self.method_status = ProcessStatus.Worked
             self.writeFile()
@@ -1067,7 +1060,7 @@ class CoreWsdl(CoreServiceInterface):
         def writeFile(self):
             """ write data in file """
             from .baseClass import Basic
-            from calculate.core.server.gen_pid import ProcessMode
+            from .gen_pid import ProcessMode
 
             if not os.path.exists(Basic.pids):
                 makeDirectory(Basic.pids)
@@ -1083,7 +1076,7 @@ class CoreWsdl(CoreServiceInterface):
 
             pid_file = path.join(Basic.pids, '%d.pid' % self.pid)
             try:
-                with open(pid_file, 'w') as f:
+                with open(pid_file, 'wb') as f:
                     d = {'name': self.process_dict['method_name'],
                          'mode': ProcessMode.CoreDaemon,
                          'os_pid': os.getpid(),
@@ -1141,7 +1134,7 @@ class CoreWsdl(CoreServiceInterface):
                 id = random.randint(1, self.Num)
             self.progress_dict['id'] = id
             self.progress_dict[id] = ReturnProgress(0, '', '')
-            self.addMessage(type='progress', id=id)
+            self.addMessage(message_type='progress', id=id)
 
         def printTable(self, table_name, head, body, fields=None,
                        onClick=None, addAction=None, step=None,
@@ -1152,23 +1145,24 @@ class CoreWsdl(CoreServiceInterface):
 
             from .api_types import Table
 
-            table = Table(head=head, body=map(lambda x: map(str, x), body),
+            table = Table(head=head, body=[[str(y) for y in x] for x in body],    
                           fields=fields,
                           onClick=onClick, addAction=addAction, step=step,
                           values=None, records=records)
             self.table_dict[id] = table
-            self.addMessage(type='table', message=table_name, id=id)
+            self.addMessage(message_type='table', message=table_name, id=id)
 
-        def addMessage(self, type='normal', message=None, id=None,
+        def addMessage(self, message_type='normal', message=None, id=None,
                        onlyShow='', default=None):
             from .api_types import Message
-
+            if isinstance(message, bytes):
+                message = message.decode("UTF-8")
             re_clean = re.compile('\[(?:\d+;)?\d+m')
             messageObj = Message(
-                type=type,
+                message_type=message_type,
                 message=(
                     None if message in (None, True, False)
-                    else re_clean.sub('', filter(lambda x: x >= ' ', message))),
+                     else re_clean.sub('', message)),
                 result=message if message in (True, False) else None,
                 id=id, onlyShow=onlyShow, default=default)
             try:
@@ -1176,7 +1170,7 @@ class CoreWsdl(CoreServiceInterface):
             except BaseException as e:
                 if isinstance(e, KeyboardInterrupt):
                     raise
-                print(_(("%s:" % type) + str(message)))
+                print(_(("%s:" % message_type) + str(message)))
 
         def dropProgress(self):
             perc = self.getProgress()
@@ -1190,45 +1184,45 @@ class CoreWsdl(CoreServiceInterface):
 
         def printSUCCESS(self, message='', onlyShow=None):
             self.dropProgress()
-            self.addMessage(type='normal', message=message,
+            self.addMessage(message_type='normal', message=message,
                             onlyShow=onlyShow)
 
         def printPre(self, message='', onlyShow=None):
             self.dropProgress()
-            self.addMessage(type='pre', message=message,
+            self.addMessage(message_type='pre', message=message,
                             onlyShow=onlyShow)
 
         def printDefault(self, message='', onlyShow=None):
             self.dropProgress()
-            self.addMessage(type='plain', message=message,
+            self.addMessage(message_type='plain', message=message,
                             onlyShow=onlyShow)
 
         def printWARNING(self, message, onlyShow=None):
             self.dropProgress()
-            self.addMessage(type='warning', message=message,
+            self.addMessage(message_type='warning', message=message,
                             onlyShow=onlyShow)
 
         def printERROR(self, message='', onlyShow=None):
             self.dropProgress()
-            self.addMessage(type='error', message=message,
+            self.addMessage(message_type='error', message=message,
                             onlyShow=onlyShow)
 
         def startTask(self, message, progress=False, num=1):
             if progress:
-                self.addMessage(type='startTask', message=message, id=num)
+                self.addMessage(message_type='startTask', message=message, id=num)
                 self.addProgress()
             else:
-                self.addMessage(type='startTask', message=message, id=num)
+                self.addMessage(message_type='startTask', message=message, id=num)
 
         def setTaskNumber(self, number=None):
-            self.addMessage(type='taskNumber', message=str(number))
+            self.addMessage(message_type='taskNumber', message=str(number))
 
         def endTask(self, result=None, progress_message=None):
-            self.addMessage(type='endTask', message=result)
+            self.addMessage(message_type='endTask', message=result)
             self.setProgress(100, progress_message)
 
         def askConfirm(self, message, default="yes"):
-            self.addMessage(type='confirm', message=message, default=default)
+            self.addMessage(message_type='confirm', message=message, default=default)
             ret = self.getAnswer()
             if ret == "":
                 return default
@@ -1238,32 +1232,32 @@ class CoreWsdl(CoreServiceInterface):
             return True
 
         def askChoice(self, message, answers=(("yes", "Yes"), ("no", "No"))):
-            self.addMessage(type='choice', message="%s|%s" % (
+            self.addMessage(message_type='choice', message="%s|%s" % (
                 message,
-                ",".join(map(lambda x: "%s(%s)" % (x[0], x[1]), answers))))
+                ",".join(("%s(%s)" % (x[0], x[1]) for x in answers))))
             return self.getAnswer()
 
         def askQuestion(self, message):
-            self.addMessage(type='question', message=message)
+            self.addMessage(message_type='question', message=message)
             return self.getAnswer()
 
         def askPassword(self, message, twice=False):
             pas_repeat = 2 if twice else 1
-            self.addMessage(type='password', message=message,
+            self.addMessage(message_type='password', message=message,
                             id=pas_repeat)
             return self.getAnswer()
 
         def beginFrame(self, message=None):
-            self.addMessage(type='beginFrame', message=message)
+            self.addMessage(message_type='beginFrame', message=message)
 
         def endFrame(self):
-            self.addMessage(type='endFrame')
+            self.addMessage(message_type='endFrame')
 
         def startGroup(self, message):
-            self.addMessage(type='startGroup', message=message)
+            self.addMessage(message_type='startGroup', message=message)
 
         def endGroup(self):
-            self.addMessage(type='endGroup')
+            self.addMessage(message_type='endGroup')
 
             # def cache(self, param):
             # sid = self.process_dict['sid']
@@ -1380,6 +1374,8 @@ class CoreWsdl(CoreServiceInterface):
             fd.close()
             com.endFrame()
 
+
+    @staticmethod
     def serv_view_cert_right(cls, cert_id, data_path, client_type=None):
         """ rights for the selected certificate """
         try:
@@ -1398,7 +1394,7 @@ class CoreWsdl(CoreServiceInterface):
             OpenSSL.SSL.FILETYPE_PEM, cert)
         com = certobj.get_extension(
             certobj.get_extension_count() - 1).get_data()
-        groups = com.split(':')[1]
+        groups = com.split(b':')[1].decode("UTF-8")
         groups_list = groups.split(',')
         # except:
         # return ['-1']
@@ -1484,8 +1480,7 @@ class CoreWsdl(CoreServiceInterface):
     @staticmethod
     def get_lang(cls, sid, method_name=""):
         """ get clients lang """
-        # print("-------------------------------------")
-        # print("DEBUG get_lang")
+
 
         lang = None
         SIDS_DIR = cls.sids
@@ -1495,18 +1490,10 @@ class CoreWsdl(CoreServiceInterface):
             if os.path.exists(sid_file):
                 # fd = open(sid_file, 'r')
 
-                with open(sid_file, 'r') as fd:
+                with open(sid_file, 'rb') as fd:
                     try:
-                        # print("file exists: %s " % sid_file)
-                        # print("sid: %s" % sid)
                         list_sid = pickle.load(fd)
                         list_sid_sid = int(list_sid[0])
-                        # print(list_sid)
-                        # print(list_sid_sid)
-                        # print(sid)
-                        # print(sid == list_sid_sid)
-                        # print(type(list_sid_sid))
-                        # print(type(sid))
                         if sid == list_sid_sid:
                             # print("SID FOUND")
                             lang = list_sid[3]
@@ -1570,7 +1557,7 @@ def create_symlink(data_path, old_data_path):
                 os.symlink(core_wrapper, link_path)
                 fd.write(link_path + '\n')
             except OSError as e:
-                print(e.message)
+                print(e)
             print(_('Symlink %s created') % link_path)
 
     temp_text_file = ''
@@ -1730,8 +1717,6 @@ class WsdlMeta(type):
             
             #total hack: carry over info_class for later use
             func.__func__.info_class = info_class
-            # return func
-        # else:
         return func
 
     @classmethod
@@ -1745,7 +1730,7 @@ class WsdlMeta(type):
             if callable(v):
                 v = v(dv)
             else:
-                if isinstance(v, (str, unicode)):
+                if isinstance(v, (str)):
                     v = Variable._value_formatter.format(v, dv.Get)
             dv.Set(k.strip('!'), v, force=k.endswith('!'))
 
@@ -1756,15 +1741,13 @@ class WsdlMeta(type):
         """
         # @staticmethod
         def wrapper(cls, sid, params):
-            # print("DEBUG view constructor")
             dv = cls.get_cache(sid, kwargs["method_name"], "vars")
-            # print("got dv from cache: %s " % dv)
             lang_changed = False
             if kwargs["groups"]:
                 def group(*args, **kwargs):
-                    if isinstance(kwargs.get('normal', ()), (unicode, str)):
+                    if isinstance(kwargs.get('normal', ()), (str)):
                         raise DataVarsError(_("Wrong normal varaiables list"))
-                    if isinstance(kwargs.get('expert', ()), (unicode, str)):
+                    if isinstance(kwargs.get('expert', ()), (str)):
                         raise DataVarsError(_("Wrong expert varaiables list"))
 
                 for gr in kwargs['groups']:
@@ -1772,7 +1755,6 @@ class WsdlMeta(type):
             if not dv:
                 dv = getattr(cls, "%s_vars" % kwargs["method_name"])(cls,
                     params=params)
-                # print("got dv from cls: %s" % dv)
                 if hasattr(params, "clienttype"):
                     if params.clienttype == 'gui' and "guivars" in kwargs:
                         mcs.modify_datavars(dv, kwargs['guivars'])
@@ -1782,14 +1764,11 @@ class WsdlMeta(type):
             else:
                 # костыль для метода install, который меняет локализацию
                 # интрефейса в зависимости от выбранного параметра lang
-                # print("dv groups: %s" % bool(dv.getGroups()))
                 if kwargs["method_name"] == 'install':
                     lang_changed = cls.fixInstallLocalization(cls, sid, dv)
                     lang = dv.Get('install.os_install_locale_lang')
                     cls.set_cache(sid, "install", "lang", lang, smart=False)
-                # print("dv before refresh groups: %s" % bool(dv.getGroups()))
                 dv.processRefresh()
-                # print("dv after refresh groups: %s" % bool(dv.getGroups()))
 
             cls.set_cache(sid, kwargs["method_name"], "vars", dv, smart=False)
             if "brief" in kwargs and "name" in kwargs['brief']:
@@ -1798,18 +1777,11 @@ class WsdlMeta(type):
                 brief_label = None
             
             if kwargs["groups"]:
-                # print("group view info creation")
-                # print(params)
-                # print(dv)
-                # print(brief_label)
-                # print(dv.getGroups())
-                # print("dv groups: %s" % bool(dv.getGroups()))
                 view = ViewInfo(dv, viewparams=params,
                                 has_brief="brief" in kwargs,
                                 allsteps=lang_changed,
                                 brief_label=brief_label)
             else:
-                # print("creating empty viewInfo")
                 view = ViewInfo()
             return view
 
@@ -1861,11 +1833,11 @@ class WsdlMeta(type):
         return wrapper
 
 
-class WsdlBase(object):
+class WsdlBase(metaclass=WsdlMeta):
     """
     Базовый класс для автосоздания методов по описанию methods
     """
-    __metaclass__ = WsdlMeta
+    # __metaclass__ = WsdlMeta
 
 
 def clearDataVars(func):
@@ -1877,7 +1849,7 @@ def clearDataVars(func):
 
     return wrapper
 
-class CustomButton(object):
+class CustomButton():
     @classmethod
     def sort_argv(cls, args):
         behavior = []
@@ -1903,7 +1875,7 @@ class CustomButton(object):
     def next_button(cls, id=None, label=None):
         return id, label, None, "button_next"
 
-    class Behavior(object):
+    class Behavior():
         @classmethod
         def link(cls, source=None, target=None):
             return "%s=%s" % (target, source)
