@@ -14,20 +14,22 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+
+ 
 import os
 import pickle
 import threading
 from os import path
 import random
-from calculate.core.server.core_interfaces import CoreServiceInterface
+from .core_interfaces import CoreServiceInterface
 from calculate.lib.utils.files import listDirectory, readFile, readLinesFile
 from calculate.lib.utils.tools import ignore
 import socket
 
-from cert_cmd import find_cert_id
+from .cert_cmd import find_cert_id
 
 
-class ProcessStatus(object):
+class ProcessStatus():
     SuccessFinished = 0
     Worked = 1
     FailedFinished = 2
@@ -35,7 +37,7 @@ class ProcessStatus(object):
     Paused = 4
 
 
-class ProcessMode(object):
+class ProcessMode():
     CoreDaemon = "core"
     LocalCall = "local"
 
@@ -48,6 +50,7 @@ def get_symlink_commands():
     for line in readLinesFile(symlinks):
         yield line.strip()
     yield "/usr/bin/cl-core"
+    yield "/usr/bin/cl-core_py3"
     yield "/usr/bin/cl-update"
     yield "/usr/bin/cl-core-patch"
 
@@ -65,7 +68,7 @@ def search_worked_process(method_name, clVars,
         pids = clVars.Get('core.cl_core_pids_path')
         for pidfile in listDirectory(pids, fullPath=True):
             try:
-                status = pickle.load(open(pidfile))
+                status = pickle.load(open(pidfile, "rb"))
                 if ((method_name is None or status['name'] == method_name) and
                             status['status'] in statuses):
                     pid_path = path.join("/proc", str(status['os_pid']))
@@ -88,7 +91,7 @@ def search_worked_process2(clVars, filter_func=lambda x: True,
     pids = clVars.Get('core.cl_core_pids_path')
     for pidfile in listDirectory(pids, fullPath=True):
         try:
-            status = pickle.load(open(pidfile))
+            status = pickle.load(open(pidfile, "rb"))
             if status_filter(status) and filter_func(status):
                 pid_path = path.join("/proc", str(status['os_pid']))
                 if path.exists(pid_path):
@@ -109,7 +112,7 @@ def get_pid_info(clVars, statuses=(ProcessStatus.Worked,)):
         pids = clVars.Get('core.cl_core_pids_path')
         for pidfile in listDirectory(pids, fullPath=True):
             try:
-                status = pickle.load(open(pidfile))
+                status = pickle.load(open(pidfile, "rb"))
                 if status['status'] in statuses:
                     if path.exists(path.join("/proc", str(status['os_pid']))):
                         yield status
@@ -120,7 +123,7 @@ def get_pid_info(clVars, statuses=(ProcessStatus.Worked,)):
 
     # try:
     #    pidfile = path.join(pids,str(pid))
-    #    status = pickle.load(open(pidfile))
+    #    status = pickle.load(open(pidfile,"rb"))
     #    return status
     # except (socket.error, ValueError, IOError, KeyError, EOFError, OSError):
     #    return None
@@ -133,7 +136,7 @@ def clear_finished_pids(clVars):
     pids = clVars.Get('core.cl_core_pids_path')
     for pidfile in listDirectory(pids, fullPath=True):
         try:
-            d = pickle.load(open(pidfile))
+            d = pickle.load(open(pidfile, "rb"))
             if path.exists(path.join("/proc", str(d['os_pid']))):
                 continue
         except Exception:
@@ -239,7 +242,7 @@ class CoreWsdl(CoreServiceInterface):
             return 0
         # temp = open(cls.sids_file, 'w')
         #            temp.close()
-        fd = open(cls.sids_file, 'r')
+        fd = open(cls.sids_file, 'rb')
         while 1:
             try:
                 # read all on one record
@@ -272,7 +275,7 @@ class CoreWsdl(CoreServiceInterface):
         if meth.is_alive():
             try:
                 os.kill(meth.pid, 2)
-            except OSError, e:
-                print 'No such process %d' % meth.pid, e
+            except OSError as e:
+                print('No such process %d' % meth.pid, e)
                 return 1
         return 0
