@@ -13,6 +13,8 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+
+ 
 import pickle
 
 import sys
@@ -31,28 +33,27 @@ from calculate.lib.utils.text import tableReport
 from calculate.lib.cl_print import color_print
 from calculate.lib.datavars import VariableError, CriticalError
 from calculate.lib.cl_lang import setLocalTranslate
-from calculate.core.server.api_types import FieldAdapter
+from .api_types import FieldAdapter
 from calculate.lib.utils.tools import ignore
 from calculate.lib.utils.files import makeDirectory
-from calculate.core.result_viewer import ResultViewer
-from calculate.core.server.loaded_methods import LoadedMethods
-from calculate.core.result_viewer_gui import ProgressGui, ErrorGui, WarningGui
-from gen_pid import ProcessStatus
+from ..result_viewer import ResultViewer
+from .loaded_methods import LoadedMethods
+from ..result_viewer_gui import ProgressGui, ErrorGui, WarningGui
+from .gen_pid import ProcessStatus
 
-from methods_func import (get_method_argparser, collect_object,
+from .methods_func import (get_method_argparser, collect_object,
                           check_result_msg, get_param_pwd, _print,
                           display_error)
-from api_types import ViewInfo, ViewParams
-from cert_cmd import parse
-from methods_func import GotErrorField
-from func import shortTraceback, CommonMethods, CommonLink
+from .api_types import ViewInfo, ViewParams
+from .cert_cmd import parse
+from .methods_func import GotErrorField
+from .func import shortTraceback, CommonMethods, CommonLink
 
 _ = lambda x: x
 setLocalTranslate('cl_core3', sys.modules[__name__])
-from itertools import izip, ifilter
 
 
-class LocalCall(object):
+class LocalCall():
     method_status = ProcessStatus.NotFound
     no_progress = None
     gui_progress = None
@@ -122,7 +123,7 @@ class LocalCall(object):
 
         def writeFile(self):
             """ write data in file """
-            from calculate.core.server.gen_pid import ProcessMode
+            from .gen_pid import ProcessMode
 
             if os.getuid():
                 return
@@ -146,7 +147,7 @@ class LocalCall(object):
                 makeDirectory(pids)
             pid_file = path.join(pids, '%d.pid' % pid)
             try:
-                with open(pid_file, 'w') as f:
+                with open(pid_file, 'wb') as f:
                     d = {'name': self.method_name,
                          'mode': ProcessMode.LocalCall,
                          'os_pid': pid,
@@ -154,8 +155,8 @@ class LocalCall(object):
                          'id': build_id}
                     pickle.dump(d, f)
             except (IOError, OSError) as e:
-                print str(e)
-                print _("Failed to write the PID file %s!") % pid_file
+                print(str(e))
+                print(_("Failed to write the PID file %s!") % pid_file)
 
         def isInteractive(self):
             """
@@ -186,7 +187,10 @@ def local_method(metaObject, args, unknown_args):
     import os
 
     sym_link = os.path.basename(sys.argv[0])
-    if sym_link != 'cl-core':
+    # sym_link = "cl-core"
+    #TODO uncomment
+    # if not (sym_link == 'cl-core' or  sym_link == 'cl-core_py3'):
+    if False:
         if sym_link in LoadedMethods.conMethods.keys():
             args.method = LoadedMethods.conMethods[sym_link][0]
         else:
@@ -197,7 +201,7 @@ def local_method(metaObject, args, unknown_args):
         for k, v in sorted(LoadedMethods.conMethods.items(),
                            key=lambda x: x[1]):
             name, user, title = v
-            print "%s - %s" % (name, title)
+            print("%s - %s" % (name, title))
         return 0
 
     colorPrint = color_print()
@@ -219,6 +223,7 @@ def local_method(metaObject, args, unknown_args):
             try:
                 view = getattr(metaObject, method_view_name)(metaObject, 0, view_obj)
             except AttributeError:
+                print("DE")
                 colorPrint.printERROR(_('Method not found: ') + method_view_name)
                 return 1
             try:
@@ -314,7 +319,7 @@ def call_method(metaObject, args, unknown_args, colorPrint):
     except Exception:
         import traceback
 
-        for i in apply(traceback.format_exception, sys.exc_info()):
+        for i in traceback.format_exception(*sys.exc_info()):
             sys.stderr.write(i)
         sys.stderr.flush()
         raise
@@ -335,7 +340,7 @@ def call_method(metaObject, args, unknown_args, colorPrint):
         while True:
             method_result = getattr(metaObject, method_name)(metaObject, 0, param_object)
             if not method_result:
-                print _('Method not available')
+                print(_('Method not available'))
                 return None
 
             if method_result[0].type and method_result[0].type != "pid":
@@ -402,7 +407,7 @@ def call_method(metaObject, args, unknown_args, colorPrint):
                                                  stdin_passwd=stdin_passwd)
             else:
                 break
-    except VariableError, e:
+    except VariableError as e:
         _print(e)
         return None
     #for ReturnedMessage in method_result:
@@ -414,7 +419,7 @@ def call_method(metaObject, args, unknown_args, colorPrint):
     #        #        if field.name == ReturnedMessage.field:
     #        #            params_text += getErrorOnParam(args, field)
     #        # colorPrint.printERROR('\r' + params_text % \
-    #        #                      str(ReturnedMessage.message))
+    #        #                      str(ReturnedMessage))
     #        return None
     return method_result
 
@@ -443,7 +448,7 @@ def print_brief(view, brief_label):
 class ColorTable(tableReport):
     def __init__(self, head, body, printer, head_printer=None,
                  line_printer=None, body_printer=None):
-        super(ColorTable, self).__init__(None, head, body, colSpan=0)
+        super().__init__(None, head, body, colSpan=0)
         self.default_printer = printer
         self.line_printer = line_printer or printer
         self.head_printer = head_printer or printer
@@ -452,7 +457,7 @@ class ColorTable(tableReport):
         self.body = body
 
 
-class Display(object):
+class Display():
     def __init__(self):
         self._print = get_terminal_print(color_print().defaultPrint)
 
@@ -499,7 +504,7 @@ class Display(object):
         self._print("\n")
 
 
-class InformationElement(object):
+class InformationElement():
     def __init__(self, field, display):
         self.value = ""
         self.label = ""
@@ -534,14 +539,14 @@ class InformationElement(object):
 
 class ValueInfo(InformationElement):
     def __init__(self, field, display):
-        super(ValueInfo, self).__init__(field, display)
+        super().__init__(field, display)
         self.value = field.value or ''
         self.label = field.label
 
 
 class CheckInfo(InformationElement):
     def __init__(self, field, display):
-        super(CheckInfo, self).__init__(field, display)
+        super().__init__(field, display)
         self.label = field.label
         map_answer = {'on': _('yes'), 'off': _("no"), 'auto': _('auto')}
         self.value = map_answer.get(field.value, field.value)
@@ -549,7 +554,7 @@ class CheckInfo(InformationElement):
 
 class ChoiceInfo(InformationElement):
     def __init__(self, field, display):
-        super(ChoiceInfo, self).__init__(field, display)
+        super().__init__(field, display)
         self.label = field.label or ''
         if field.choice and field.comments:
             map_comment = dict(zip(field.choice, field.comments))
@@ -560,7 +565,7 @@ class ChoiceInfo(InformationElement):
 
 class MultiChoiceInfo(InformationElement):
     def __init__(self, field, display):
-        super(MultiChoiceInfo, self).__init__(field, display)
+        super().__init__(field, display)
         self.label = field.label or ''
         if field.listvalue:
             value = field.listvalue
@@ -578,7 +583,7 @@ class MultiChoiceInfo(InformationElement):
 
 class ErrorInfo(InformationElement):
     def __init__(self, field, display):
-        super(ErrorInfo, self).__init__(field, display)
+        super().__init__(field, display)
         self.label = field.label
 
     def show(self):
@@ -592,7 +597,7 @@ class TableInfo(InformationElement):
 
     def map_row(self, row, typedata):
         map_answer = {'on': _('yes'), 'off': _("no"), 'auto': _('auto')}
-        for cell, typefield in izip(row, typedata):
+        for cell, typefield in zip(row, typedata):
             if typefield in ['check', 'check_tristate']:
                 yield map_answer.get(cell, cell) or ""
             elif "password" in typefield:
@@ -601,14 +606,14 @@ class TableInfo(InformationElement):
                 yield cell or ""
 
     def __init__(self, field, display):
-        super(TableInfo, self).__init__(field, display)
+        super().__init__(field, display)
         self.label = field.label
         self.head = field.tablevalue.head
 
         # удаление первого элемента строки (для wsdl)
         body = [x[1:] if x and not x[0] else x for x in field.tablevalue.body]
 
-        if not filter(None, map(lambda x: x, body)):
+        if not [x for x in [x for x in body] if x]:
             self.body = None
         else:
             type_values = [x.typefield for x in field.tablevalue.values]
@@ -624,11 +629,11 @@ def print_brief_group(Fields, group_name):
     display = Display()
     show_group = True
     try:
-        for element in ifilter(None,
-                               (InformationElement.from_field(
-                                   FieldAdapter.from_detect(x),
-                                   display)
-                                for x in Fields if not x.uncompatible)):
+        for element in (x for x 
+                in (InformationElement.from_field(FieldAdapter.from_detect(y),display) for y 
+                    in Fields 
+                    if not y.uncompatible) 
+                if x):
             if show_group:
                 display.print_group(group_name)
                 show_group = False
@@ -645,7 +650,7 @@ class Methods(LocalCall.Common, object):
 
     def __new__(cls, *args, **kwargs):
         if not cls._instance:
-            cls._instance = super(Methods, cls).__new__(
+            cls._instance = super().__new__(
                 cls, *args, **kwargs)
         return cls._instance
 
