@@ -14,23 +14,27 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+
+ 
 from spyne.server.wsgi import WsgiApplication
 
 import re
 import logging
 import os
 #cStringIO was moved to io in python3
-import cStringIO as io
+import io
 
 logger = logging.getLogger(__name__)
 
 import datetime
 import pickle
-from loaded_methods import LoadedMethods
+from .loaded_methods import LoadedMethods
 
 # for OpenSSLAdapter
 import calculate.contrib
-from cherrypy.wsgiserver.ssl_pyopenssl import pyOpenSSLAdapter
+# from cherrypy.wsgiserver.ssl_pyopenssl import pyOpenSSLAdapter
+from cheroot.ssl.pyopenssl import pyOpenSSLAdapter
+
 
 HTTP_500 = '500 Internal server error'
 HTTP_200 = '200 OK'
@@ -45,17 +49,16 @@ not_log_list = ['post_server_request', 'post_client_request', 'del_sid',
 
 class ClApplication(WsgiApplication):
     def __init__(self, app, log=None):
-        super(ClApplication, self).__init__(app)
+        super().__init__(app)
         # add object logging
         self.log = logger
 
     #verification of compliance certificate and session (sid)
     def check_cert_sid(self, sid, server):
         import threading
-
         curthread = threading.currentThread()
         cert = curthread.client_cert
-        from cert_cmd import find_cert_id
+        from .cert_cmd import find_cert_id
 
         cert_id = find_cert_id(cert, server.data_path, server.certbase)
         cert_id = int(cert_id)
@@ -67,8 +70,8 @@ class ClApplication(WsgiApplication):
             os.system('mkdir %s' % server.sids)
 
         if not os.path.isfile(server.sids_file):
-            open(server.sids_file, 'w').close()
-        with open(server.sids_file, 'r') as fd:
+            open(server.sids_file, 'wb').close()
+        with open(server.sids_file, 'rb') as fd:
             while 1:
                 try:
                     # read all on one record
@@ -111,27 +114,28 @@ class ClApplication(WsgiApplication):
                 return 0
             return 1
 
-        if (sid and
+        if (sid is not None and
             (method_name in LoadedMethods.rightsMethods or
             method_name.endswith('_view') and
             method_name[:-5] in LoadedMethods.rightsMethods)):
             if not self.check_cert_sid(sid, curthread.server):
                 return 0
-
-        with open(server_cert, 'r') as f:
+        
+        with open(server_cert, 'rb') as f:
             data_server_cert = f.read()
         certobj = OpenSSL.crypto.load_certificate(
             OpenSSL.SSL.FILETYPE_PEM, data_server_cert)
 
-        with open(server_key, 'r') as f:
+        with open(server_key, 'rb') as f:
             data_server_key = f.read()
         Pkey = OpenSSL.crypto.load_privatekey(OpenSSL.SSL.FILETYPE_PEM,
-                                              data_server_key, 'qqqq')
+                                              data_server_key, b'qqqq')
+                        
         signature = OpenSSL.crypto.sign(Pkey, cert, 'SHA1')
         try:
             OpenSSL.crypto.verify(certobj, signature, cert, 'SHA1')
         except Exception as e:
-            print e
+            print(e)
             return 0
         if method_name == 'cert_add':
             return 0
@@ -139,16 +143,17 @@ class ClApplication(WsgiApplication):
             OpenSSL.SSL.FILETYPE_PEM, cert)
         try:
             com = certobj_cl.get_extension(certobj_cl.get_extension_count() - 1)
-            groups = com.get_data().split(':')[1]
+            groups = com.get_data().split(b':')[1].decode("UTF-8")
         except IndexError:
             groups = ""
-        except Exception:
+        except Exception as e:
+            print(e)
             return 0
         groups_list = groups.split(',')
         # open certificates database
         if not os.path.exists(certbase):
             open(certbase, "w").close()
-        from cert_cmd import find_cert_id
+        from .cert_cmd import find_cert_id
 
         checked_id = find_cert_id(cert, data_path, certbase)
         cert_id = int(checked_id)
@@ -299,15 +304,18 @@ class ClApplication(WsgiApplication):
         """
         if (not "wsgi.input" in http_req_env):
             return None
+        # print(http_req_env)
         length = http_req_env.get("CONTENT_LENGTH")
+        if(not length):
+            return None
         input = http_req_env["wsgi.input"]
         body = input.read(int(length))
-        res = re.search("<ns.:sid>(.*?)<\/ns.:sid>", body)
+        res = re.search(b"<ns.:sid>(.*?)<\/ns.:sid>", body)
         #horrbile hack:
         #cherrypy provides rfile in req_env which is consumed upon .read() without 
         #        workarounds, and both we and spyne need the data on it
         #so we pass a dummy with the data and read() method on to spyne
-        http_req_env["wsgi.input"] = io.StringIO(body)
+        http_req_env["wsgi.input"] = io.BytesIO(body)
         
         if(res):
             return int(res.group(1))
@@ -333,14 +341,13 @@ class ClApplication(WsgiApplication):
         sid = self.get_sid_from_soap(req_env)
         method_name = self.get_method_name_from_http(req_env)
         if method_name is None:
-            resp = "Could not extract method name from the request!"
+            resp = b"Could not extract method name from the request!"
             http_resp_headers['Content-Length'] = str(len(resp))
             start_response(HTTP_500, http_resp_headers.items())
             return [resp]
 
         service = self.app.services[0]
         import threading
-
         curthread = threading.currentThread()
         # check if client certificate exists
         if not hasattr(curthread, 'client_cert'):
@@ -357,13 +364,13 @@ class ClApplication(WsgiApplication):
                                     % (datetime.datetime.now().__str__(),
                                         finger, ip,
                                         method_name[5:]))
-            resp = "Permission denied: " + method_name
+            resp = b"Permission denied: " + method_name.encode("UTF-8")
             http_resp_headers['Content-Length'] = str(len(resp))
             start_response(HTTP_403, http_resp_headers.items())
             return [resp]
         
         
-        if sid:
+        if sid is not None:
             curthread.lang = service.get_lang(service, sid, method_name)
         if curthread.client_cert:
             certobj = OpenSSL.crypto.load_certificate(
@@ -377,7 +384,7 @@ class ClApplication(WsgiApplication):
                                         finger, ip,
                                         method_name[5:]))
 
-        return super(ClApplication, self).handle_rpc(req_env, start_response)
+        return super().handle_rpc(req_env, start_response)
 
 class OpenSSLAdapter(pyOpenSSLAdapter):
     def verify_func(self, connection, x509, errnum, errdepth, ok):
