@@ -27,7 +27,7 @@ from calculate.lib.utils.files import readFile, writeFile
 get_pkgname_by_filename = templateFunction.get_pkgname_by_filename
 
 
-class Cache(object):
+class Cache():
     reMerge = re.compile("(merge|mergepkg)\(([-\w/]*)(?:\[[^\]]\])?\)[-!=<>]")
     rePatch = re.compile("^#\s*Calculate.*ac_install_patch==on")
 
