@@ -14,13 +14,15 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import action
-import core
-import request
-import certificate
-import groups
-import setup_package
-import variable
-import backup
+
+
+from . import action
+from . import core
+from . import request
+from . import certificate
+from . import groups
+from . import setup_package
+from . import variable
+from . import backup
 
 section = "core"
